@@ -9,12 +9,13 @@ compile_error!("one of the features ['postgres', 'mysql', 'sqlite'] must be enab
 ))]
 compile_error!("only one of ['postgres', 'mysql', 'sqlite'] can be enabled");
 
-mod add_extension;
 mod auth;
 ///This Library Requires that Tower_Cookies and AxumSQLxSessions is used as an active layer.
 mod layer;
+mod service;
 mod session;
 
 pub use auth::{Auth, HasPermission, Rights};
 pub use layer::AuthSessionLayer;
+pub use service::AuthSessionService;
 pub use session::{AuthSession, Authentication};
